==> frame_s2-0.1.0.dev20220412+86-py3-none-any.whl: frame_s2/runners/run_general_dekads.sh <==
#!/bin/bash
job_name=$1
input_lst=$2
#mount_dir=/vitodata/Frame/Lv2_PROBA
#mount_dir=/vitodata/Frame/S2
#mount_dir=/vitodata/Frame/Lv1

export SPARK_MAJOR_VERSION=2
export SPARK_HOME=/usr/hdp/current/spark2-client
export PYSPARK_PYTHON="/usr/bin/python3.6"

DIRNAME=`dirname $0`
DIRNAME="${DIRNAME}/../.."
cd $DIRNAME

keyfile="frame_s2/config/mep_frame.keytab"
kinit -kt $keyfile mep_frame


zip -r "/tmp/frame_dekads.zip" frame_s2/*.py frame_s2/config/*.lst frame_s2/executables/FREQ_EVENT_MEP2.so  frame_s2/config/*.py && \
  spark-submit --master yarn --queue mep_frame --deploy-mode cluster \
  --name "${job_name}" \
  --conf spark.yarn.appMasterEnv.YARN_CONTAINER_RUNTIME_TYPE=docker --conf spark.executorEnv.YARN_CONTAINER_RUNTIME_TYPE=docker \
  --conf spark.yarn.appMasterEnv.YARN_CONTAINER_RUNTIME_DOCKER_IMAGE=vito-docker-private.artifactory.vgt.vito.be/frame_smoother \
  --conf spark.executorEnv.YARN_CONTAINER_RUNTIME_DOCKER_IMAGE=vito-docker-private.artifactory.vgt.vito.be/frame_smoother \
  --conf spark.yarn.appMasterEnv.YARN_CONTAINER_RUNTIME_DOCKER_MOUNTS=/var/lib/sss/pipes:/var/lib/sss/pipes:rw,/usr/hdp/current/:/usr/hdp/current/:ro,/etc/hadoop/conf/:/etc/hadoop/conf/:ro,/etc/krb5.conf:/etc/krb5.conf:ro,/vitodata/Frame/S2:/vitodata/Frame/S2:ro \
  --conf spark.executorEnv.YARN_CONTAINER_RUNTIME_DOCKER_MOUNTS=/var/lib/sss/pipes:/var/lib/sss/pipes:rw,/usr/hdp/current/:/usr/hdp/current/:ro,/etc/hadoop/conf/:/etc/hadoop/conf/:ro,/etc/krb5.conf:/etc/krb5.conf:ro,/vitodata/frame_6:/vitodata/frame_6:ro,/vitodata/frame_7:/vitodata/frame_7:ro,/vitodata/Frame/Lv2_tif_conversions:/vitodata/Frame/Lv2_tif_conversions:rw,/vitodata/Frame/S2:/vitodata/Frame/S2:rw,/vitodata/Frame/Lv2_PROBA:/vitodata/Frame/Lv2_PROBA:rw,/vitodata/frame_3:/vitodata/frame_3:ro,/vitodata/frame_4:/vitodata/frame_4:ro \
  --conf spark.executorEnv.INCLUDE=/usr/include/ --conf spark.yarn.appMasterEnv.PYSPARK_PYTHON=/usr/bin/python3.6 \
  --conf spark.yarn.appMasterEnv.SPARK_HOME=/usr/hdp/current/spark2-client \
  --conf spark.yarn.appMasterEnv.SPARK_HOME=/usr/hdp/current/spark2-client \
  --conf spark.yarn.appMasterEnv.PYSPARK_DRIVER_PYTHON=/usr/bin/python3.6 \
  --conf spark.executorEnv.PYSPARK_PYTHON=/usr/bin/python3.6 \
  --conf spark.shuffle.service.enabled=true --conf spark.dynamicAllocation.enabled=true \
  --conf spark.dynamicAllocation.minExecutors=1 \
  --conf spark.dynamicAllocation.maxExecutors=30 \
  --conf spark.yarn.submit.waitAppCompletion=true \
  --conf spark.executor.memoryOverhead=3500M \
  --principal "mep_frame@VGT.VITO.BE" \
  --keytab $keyfile \
  --executor-memory 512M --files frame_s2/executables/FREQ_EVENT_MEP2.so,frame_s2/config/LU_RUE.txt,frame_s2/config/colormaps/npp.txt,frame_s2/config/colormaps/ndvi.txt   --py-files /tmp/frame_dekads.zip frame_s2/wrap_per_dekad.py \
  --input_lst ${input_lst}

==> frame_s2-2.1.0.dev20220523+92-py3-none-any.whl: frame_s2/runners/run_general_dekads.sh <==
#!/bin/bash
job_name=$1
input_lst=$2
#mount_dir=/vitodata/Frame/Lv2_PROBA
#mount_dir=/vitodata/Frame/S2
#mount_dir=/vitodata/Frame/Lv1

export SPARK_MAJOR_VERSION=2
export SPARK_HOME=/usr/hdp/current/spark2-client
export PYSPARK_PYTHON="/usr/bin/python3.6"

DIRNAME=`dirname $0`
DIRNAME="${DIRNAME}/../.."
cd $DIRNAME

keyfile="frame_s2/config/mep_frame.keytab"
kinit -kt $keyfile mep_frame


zip -r "/tmp/frame_dekads.zip" frame_s2/*.py frame_s2/config/*.lst frame_s2/executables/FREQ_EVENT_MEP2.so  frame_s2/config/*.py && \
  spark-submit --master yarn --queue mep_frame --deploy-mode cluster \
  --name "${job_name}" \
  --conf spark.yarn.appMasterEnv.YARN_CONTAINER_RUNTIME_TYPE=docker --conf spark.executorEnv.YARN_CONTAINER_RUNTIME_TYPE=docker \
  --conf spark.yarn.appMasterEnv.YARN_CONTAINER_RUNTIME_DOCKER_IMAGE=vito-docker-private.artifactory.vgt.vito.be/frame_smoother \
  --conf spark.executorEnv.YARN_CONTAINER_RUNTIME_DOCKER_IMAGE=vito-docker-private.artifactory.vgt.vito.be/frame_smoother \
  --conf spark.yarn.appMasterEnv.YARN_CONTAINER_RUNTIME_DOCKER_MOUNTS=/var/lib/sss/pipes:/var/lib/sss/pipes:rw,/usr/hdp/current/:/usr/hdp/current/:ro,/etc/hadoop/conf/:/etc/hadoop/conf/:ro,/etc/krb5.conf:/etc/krb5.conf:ro,/vitodata/Frame/S2:/vitodata/Frame/S2:ro,/vitodata/frame_4:/vitodata/frame_4:ro \
  --conf spark.executorEnv.YARN_CONTAINER_RUNTIME_DOCKER_MOUNTS=/var/lib/sss/pipes:/var/lib/sss/pipes:rw,/usr/hdp/current/:/usr/hdp/current/:ro,/etc/hadoop/conf/:/etc/hadoop/conf/:ro,/etc/krb5.conf:/etc/krb5.conf:ro,/vitodata/frame_6:/vitodata/frame_6:rw,/vitodata/frame_7:/vitodata/frame_7:ro,/vitodata/Frame/Lv2_tif_conversions:/vitodata/Frame/Lv2_tif_conversions:ro,/vitodata/Frame/S2:/vitodata/Frame/S2:ro,/vitodata/Frame/Lv2_PROBA:/vitodata/Frame/Lv2_PROBA:ro,/vitodata/frame_3:/vitodata/frame_3:ro,/vitodata/frame_4:/vitodata/frame_4:ro,/data/Mars:/data/Mars:rw \
  --conf spark.executorEnv.INCLUDE=/usr/include/ --conf spark.yarn.appMasterEnv.PYSPARK_PYTHON=/usr/bin/python3.6 \
  --conf spark.yarn.appMasterEnv.SPARK_HOME=/usr/hdp/current/spark2-client \
  --conf spark.yarn.appMasterEnv.SPARK_HOME=/usr/hdp/current/spark2-client \
  --conf spark.yarn.appMasterEnv.PYSPARK_DRIVER_PYTHON=/usr/bin/python3.6 \
  --conf spark.executorEnv.PYSPARK_PYTHON=/usr/bin/python3.6 \
  --conf spark.shuffle.service.enabled=true --conf spark.dynamicAllocation.enabled=true \
  --conf spark.dynamicAllocation.minExecutors=1 \
  --conf spark.dynamicAllocation.maxExecutors=30 \
  --conf spark.yarn.submit.waitAppCompletion=true \
  --conf spark.executor.memoryOverhead=3500M \
  --principal "mep_frame@VGT.VITO.BE" \
  --keytab $keyfile \
  --executor-memory 512M --files frame_s2/executables/FREQ_EVENT_MEP2.so,frame_s2/config/LU_RUE.txt,frame_s2/config/colormaps/npp.txt,frame_s2/config/colormaps/ndvi.txt   --py-files /tmp/frame_dekads.zip frame_s2/wrap_per_dekad.py \
  --input_lst ${input_lst}
